@@ -46,6 +46,11 @@ from ericsson.deploypattern.tools import bundle
 from ericsson.deploypattern.tools import mdtcli
 from ericsson.deploypattern.version import __version__
 
+
+LOGGER = logging.getLogger()
+DFN_CONF_FILE = '/etc/deploypattern.conf'
+
+
 class LoggingLevelFilter(logging.Filter):
 
     def __init__(self, min_level=logging.NOTSET, max_level=logging.CRITICAL):
@@ -58,46 +63,57 @@ class LoggingLevelFilter(logging.Filter):
             if self.min_level <= record.levelno <= self.max_level \
             else False
 
-# create logger
-LOGGER = logging.getLogger()
-LOGGER.setLevel(logging.INFO)
 
-# Console Handlerr for stderr
-CH_ERR = logging.StreamHandler(stream=sys.stderr)
-CH_ERR.addFilter(LoggingLevelFilter(min_level=logging.ERROR))
-CH_ERR.setLevel(logging.ERROR)
-# Console Handler for stdout
-CH_OUT = logging.StreamHandler(stream=sys.stdout)
-CH_OUT.addFilter(LoggingLevelFilter(min_level=logging.DEBUG, max_level=logging.WARNING))
-CH_OUT.setLevel(logging.DEBUG)
+def logger_config(debug=False):
+    LOGGER.setLevel(logging.INFO)
 
-LOGGER.addHandler(CH_ERR)
-LOGGER.addHandler(CH_OUT)
+    # Console Handlerr for stderr
+    CH_ERR = logging.StreamHandler(stream=sys.stderr)
+    CH_ERR.addFilter(LoggingLevelFilter(min_level=logging.ERROR))
+    CH_ERR.setLevel(logging.ERROR)
+    # Console Handler for stdout
+    CH_OUT = logging.StreamHandler(stream=sys.stdout)
+    CH_OUT.addFilter(LoggingLevelFilter(min_level=logging.DEBUG, max_level=logging.WARNING))
+    CH_OUT.setLevel(logging.DEBUG)
 
-# File Handler
-FORMATTER = logging.Formatter('%(asctime)s:'
-                              '%(levelname)s:'
-                              '%(filename)s:'
-                              '%(funcName)s:'
-                              ' %(message)s')
-F_H = logging.handlers.RotatingFileHandler(
-    '/tmp/deploypattern.log', 'a', 1000000, 1)
-# F_H = logging.FileHandler('/var/log/deploypattern.log')
-F_H.setLevel(logging.INFO)
-F_H.setFormatter(FORMATTER)
-LOGGER.addHandler(F_H)
+    LOGGER.addHandler(CH_ERR)
+    LOGGER.addHandler(CH_OUT)
 
-# For Ansible Log
-# Ansible add FileHandler to root logger
-# Search ansible logger with its key: p=<PID ansible> u=<user> |
-# Don't propagate the log to parent logger (root), not to have twice log written
-# Add your Handler ansible logger to have Ansible log
-for key in logging.Logger.manager.loggerDict.keys():
-    if ' | ' in key:
-        logging.Logger.manager.loggerDict[key].propagate = False
-        logging.Logger.manager.loggerDict[key].addHandler(F_H)
+    # File Handler
+    FORMATTER = logging.Formatter('%(asctime)s:'
+                                  '%(levelname)s:'
+                                  '%(filename)s:'
+                                  '%(funcName)s:'
+                                  ' %(message)s')
+    try:
+        F_H = logging.handlers.RotatingFileHandler(
+            '/var/log/deploypattern.log', 'a', 5000000, 1)
+    except (IOError, OSError) as msg:
+        raise errors.CliError("Please use sudo for the mdt commands: %s " % msg)
 
-DFN_CONF_FILE = '/etc/deploypattern.conf'
+    F_H.setLevel(logging.INFO)
+    F_H.setFormatter(FORMATTER)
+    LOGGER.addHandler(F_H)
+
+    # For Ansible Log
+    # Ansible add FileHandler to root logger
+    # Search ansible logger with its key: p=<PID ansible> u=<user> |
+    # Don't propagate the log to parent logger (root), not to have twice log written
+    # Add your Handler ansible logger to have Ansible log
+    for key in logging.Logger.manager.loggerDict.keys():
+        if ' | ' in key:
+            logging.Logger.manager.loggerDict[key].propagate = False
+            logging.Logger.manager.loggerDict[key].addHandler(F_H)
+
+    if debug:
+        formatter = logging.Formatter('%(levelname)s:'
+                                      '%(filename)s:'
+                                      '%(funcName)s:'
+                                      ' %(message)s')
+        CH_OUT.setFormatter(formatter)
+        LOGGER.setLevel(logging.DEBUG)
+        CH_OUT.setLevel(logging.DEBUG)
+        F_H.setLevel(logging.DEBUG)
 
 
 class ArgumentParser(argparse.ArgumentParser):
@@ -214,28 +230,40 @@ For allinone installation the local disk will be used instead of NFS server
                                         help='MDT initialisation')
     load_parser = subparsers.add_parser('load',
                                         usage='mdt [mdt_options] load [resource] [command_options]',
-                                        help='Load resources')
+                                        help='Load resource')
     reset_parser = subparsers.add_parser('reset',
                                          usage='mdt [mdt_options] reset [resource] [command_options]',
-                                         help='Reset ressources')
+                                         help='Reset resource')
     set_parser = subparsers.add_parser('set',
                                        usage='mdt [mdt_options] set [resource] [command_options]',
-                                       help='Set ressources')
+                                       help='Set resource')
     unset_parser = subparsers.add_parser('unset',
                                          usage='mdt [mdt_options] unset [resource] [command_options]',
-                                         help='Unset ressources')
+                                         help='Unset resource')
     add_val_parser = subparsers.add_parser('add',
                                            usage='mdt [mdt_options] add [resource] [command_options]',
-                                           help='Add ressources')
+                                           help='Add resource')
     delete_parser = subparsers.add_parser('delete',
                                           usage='mdt [mdt_options] delete [resource] [command_options]',
-                                          help='Delete ressources')
+                                          help='Delete resource')
     upgrade_parser = subparsers.add_parser('upgrade',
                                            usage='mdt [mdt_options] upgrade [resource] [command_options]',
-                                           help='Upgrade ressources')
+                                           help='Upgrade resource')
+    rollback_parser = subparsers.add_parser('rollback',
+                                            usage='mdt [mdt_options] rollback [resource] [command_options]',
+                                            help='Rollback ressources')
     audit_parser = subparsers.add_parser('audit',
                                          usage='mdt [mdt_options] audit [resource] [command_options]',
-                                         help='Audit ressources')
+                                         help='Audit resource')
+    backup_parser = subparsers.add_parser('backup',
+                                          usage='mdt [mdt_options] backup [resource] [command_options]',
+                                          help='Backup resource')
+    restore_parser = subparsers.add_parser('restore',
+                                           usage='mdt [mdt_options] restore [resource] [command_options]',
+                                           help='Restore resource')
+    status_parser = subparsers.add_parser('status',
+                                        usage='mdt [mdt_options] status [resource] [command_options]',
+                                        help='Status resource' )
     # Command deploy
     # -----------------
     deploy_sub_parser = deploy_parser.add_subparsers(dest='cmd_deploy')
@@ -326,6 +354,23 @@ The inventory, list of nodes, is given by the mdt-matrix file in the config bund
     load_cfg_parser = load_sub_parser.add_parser('cfg', add_help=False)
     load_cfg_parser.set_defaults(func=redirect_to_cli('load cfg'))
 
+    # Command backup
+    # --------------
+    backup_sub_parser = backup_parser.add_subparsers(dest='cmd_backup')
+    backup_database_parser = backup_sub_parser.add_parser(
+        'database', add_help=False)
+    backup_database_parser.set_defaults(
+        func=redirect_to_cli('backup database'))
+
+    # Command restore
+    # ---------------
+    restore_sub_parser = restore_parser.add_subparsers(dest='cmd_restore')
+    restore_database_parser = restore_sub_parser.add_parser(
+        'database', add_help=False)
+    restore_database_parser.set_defaults(
+        func=redirect_to_cli('restore database'))
+
+
     # Command audit
     # -------------
     audit_sub_parser = audit_parser.add_subparsers(dest='cmd_audit')
@@ -484,7 +529,7 @@ The deb are pushed to the local deb repository.
     delete_sub_parser = delete_parser.add_subparsers(dest='cmd_delete')
     delete_profile_parser = delete_sub_parser.add_parser('profile', add_help=False)
     delete_profile_parser.set_defaults(func=redirect_to_cli('delete profile'))
-    ## US 45690 - LRO
+    # US 45690 - LRO
     delete_chart_parser = delete_sub_parser.add_parser('chart', add_help=False)
     delete_chart_parser.set_defaults(func=redirect_to_cli('delete chart'))
 
@@ -494,6 +539,21 @@ The deb are pushed to the local deb repository.
     upgrade_products_parser = upgrade_sub_parser.add_parser('products', add_help=False)
     upgrade_products_parser.set_defaults(func=redirect_to_cli('upgrade products'))
 
+    # US 59826 - LRO
+    # Command status (cli)
+    # --------------------
+    status_sub_parser = status_parser.add_subparsers(dest='cmd_status')
+    status_products_parser = status_sub_parser.add_parser('products', add_help=False)
+    status_products_parser.set_defaults(func=redirect_to_cli('status products'))
+
+    # Command rollback
+    # ----------------
+    rollback_sub_parser = rollback_parser.add_subparsers(dest='cmd_rollback')
+    rollback_products_parser = rollback_sub_parser.add_parser(
+        'products', add_help=False)
+    rollback_products_parser.set_defaults(
+        func=redirect_to_cli('rollback products'))
+
     # inventory_parser = subparsers.add_parser('inventory',
     #                                          help='Inventory management (MDT <1.5)')
     # inventory_parser.add_argument("--debug",
@@ -544,7 +604,8 @@ def __get_cfg():
         os.mkdir('/opt/mfvp/deploypattern/bundle', 0755)
     except Exception as error:
         pass
-    mdtcli.call_mdt_cli('get', 'cfg', ['-o', '/opt/mfvp/deploypattern/bundle/bundle.tgz'])
+    mdtcli.call_mdt_cli(
+        'get', 'cfg', ['-o', '/opt/mfvp/deploypattern/bundle/bundle.tgz'])
     try:
         tar = tarfile.open('/opt/mfvp/deploypattern/bundle/bundle.tgz')
         tar.extractall('/opt/mfvp/deploypattern/bundle/')
@@ -553,9 +614,9 @@ def __get_cfg():
         LOGGER.error("Get bundle failed: %s", msg.message)
         return 1
 
+
 def __clean_cfg():
     """
-
     :return:
     """
     try:
@@ -564,23 +625,18 @@ def __clean_cfg():
         LOGGER.error("Clean bundle failed: %s", msg.message)
         return 1
 
+
 def main():
     """ Main """
-
     # setup signal handler
     signal.signal(signal.SIGINT, signal_handler)
     # parse cmdline args
     args, unknown_args = parse_cmdline()
 
     if args.debug:
-        formatter = logging.Formatter('%(levelname)s:'
-                                      '%(filename)s:'
-                                      '%(funcName)s:'
-                                      ' %(message)s')
-        CH_OUT.setFormatter(formatter)
-        LOGGER.setLevel(logging.DEBUG)
-        CH_OUT.setLevel(logging.DEBUG)
-        F_H.setLevel(logging.DEBUG)
+        logger_config(args.debug)
+    else:
+        logger_config()
 
     # Command mdt init
     # ---------------------
@@ -609,7 +665,8 @@ def main():
                              thirdparty_path=args.thirdparty_path,
                              http_port=args.http_port)
         except Exception as msg:
-            LOGGER.error("Initialization failed: %s", msg.message, exc_info=True)
+            LOGGER.error("Initialization failed: %s",
+                         msg.message, exc_info=True)
             return 1
 
     # check if init as been done before going on
@@ -853,6 +910,47 @@ def main():
                 LOGGER.error("Upgrade products failed: %s", msg.message)
                 return 1
 
+    # Command mdt upgrade
+    # -------------------------
+    if args.cmd == 'rollback':
+        if args.cmd_rollback == 'products':
+            try:
+                mdtcli.call_mdt_cli('rollback', 'products', unknown_args)
+            except Exception as msg:
+                LOGGER.error("Rollback products failed: %s", msg.message)
+                return 1
+
+    # Command mdt backup
+    # -------------------------
+    if args.cmd == 'backup':
+        if args.cmd_backup == 'database':
+            try:
+                mdtcli.call_mdt_cli('backup', 'database', unknown_args)
+            except Exception as msg:
+                LOGGER.error("Backup database failed: %s", msg.message)
+                return 1
+
+    # Command mdt restore
+    # -------------------------
+    if args.cmd == 'restore':
+        if args.cmd_restore == 'database':
+            try:
+                mdtcli.call_mdt_cli('restore', 'database', unknown_args)
+            except Exception as msg:
+                LOGGER.error("Restore database failed: %s", msg.message)
+                return 1
+
+    # US 59826 - LRO
+    # Command mdt status
+    # ------------------
+    if args.cmd == 'status':
+        if args.cmd_status == 'products':
+            try:
+                mdtcli.call_mdt_cli('status', 'products', unknown_args)
+            except Exception as msg:
+                LOGGER.error("Status products failed: %s", msg.message)
+                return 1
+
     if unknown_args:
         LOGGER.error("Unknown arguments : %s", unknown_args)
         exit(2)
