@@ -62,6 +62,7 @@ THIRD_PART_LIST = ['mongo', 'rabbitmq', 'redis']
 
 RE_IP = re.compile('\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}$')
 
+
 class Bundle(object):
     """
     From config bundle actions
@@ -152,7 +153,8 @@ class Bundle(object):
                     inventory_dict_list[index[0]][matrix[TYPE]].append(
                         {'name': matrix[NODE], "access_ip": ip})
                 except Exception as msg:
-                    LOGGER.error("Hostname %s unreachable, cannot gather hostname info", matrix[NODE])
+                    LOGGER.error(
+                        "Hostname %s unreachable, cannot gather hostname info", matrix[NODE])
                     return 1
 
         # copy master to node group to be able to deploy pod on them
@@ -463,7 +465,9 @@ class Bundle(object):
                 vars=get_config_vars_dict(),
                 extra_vars=var_dict,
                 manage_callback=True,
-                next_status="deploymentInProgress")
+                next_status="deploymentInProgress",
+                last_playbook=False,
+                category="deploy")
             LOGGER.debug("result : %s", result)
             if result != 0:
                 # send status to api
@@ -478,7 +482,8 @@ class Bundle(object):
                 vars=get_config_vars_dict(),
                 extra_vars=var_dict,
                 manage_callback=True,
-                next_status="deploymentInProgress")
+                next_status="deploymentInProgress",
+                category="deploy")
             LOGGER.debug("result : %s", result)
 
             if result != 0:
@@ -534,7 +539,8 @@ class Bundle(object):
             vars=conf_var_dict,
             extra_vars=var_dict,
             manage_callback=True,
-            next_status="configured")
+            next_status="configured",
+            category="reset")
         LOGGER.debug("result : %s", result)
         if result != 0:
             api = "api/mdt/kube/cluster/status"
@@ -698,7 +704,7 @@ class Bundle(object):
         LOGGER.debug(":: Audit kube-cluster")
 
         ## LRO - review
-        ## Pb if node_name is hostname we don't set IP address in inventory
+        # Pb if node_name is hostname we don't set IP address in inventory
 
         # retreive nodes through api
         response = self.get_api("api/mdt/kube/cluster/nodes")
@@ -720,7 +726,8 @@ class Bundle(object):
             # LRO - Add it to node_list for future callback
             # We assume that node parameter is passed like set in matrix or not ?
             # If parameter is hostname, serach its IP address to always check
-            # existence with IP Address always in inventory with parameter access_ip
+            # existence with IP Address always in inventory with parameter
+            # access_ip
             if not RE_IP.match(node_name):
                 # node-name is hostname
                 # Search IP address, in /etc/hosts or with DNS
@@ -734,19 +741,22 @@ class Bundle(object):
                 node_ip, port = sockaddr
             else:
                 node_ip = node_name
-            if node_ip in [ node['access_ip'] for node in inventory[0][KUBE_MASTER]]:
+            if node_ip in [node['access_ip'] for node in inventory[0][KUBE_MASTER]]:
                 node_found = True
                 node_list.append(str(node_name))
                 # We update inventory: remove node except masters
-                kube_node_inventory = {KUBE_NODE: [{'children': 'kube-master'}]}
+                kube_node_inventory = {
+                    KUBE_NODE: [{'children': 'kube-master'}]}
                 inventory[1][KUBE_NODE] = kube_node_inventory[KUBE_NODE]
             # for KUBE_NODE, there is a children KUBE-MASTER
-            elif node_ip in [ node['access_ip'] for node in inventory[1][KUBE_NODE] if not 'children' in node.keys()]:
+            elif node_ip in [node['access_ip'] for node in inventory[1][KUBE_NODE] if not 'children' in node.keys()]:
                 node_found = True
                 node_list.append(str(node_name))
                 # We update inventory
-                # Build KUBE_NODE with always KUBE_MASTER and only the node passed by parameter
-                kube_node_inventory = {KUBE_NODE: [{'children': 'kube-master'}]}
+                # Build KUBE_NODE with always KUBE_MASTER and only the node
+                # passed by parameter
+                kube_node_inventory = {
+                    KUBE_NODE: [{'children': 'kube-master'}]}
                 kube_node_inventory[KUBE_NODE].append(
                     {'access_ip': str(node_ip),
                      'ip': str(node_ip),
@@ -757,7 +767,6 @@ class Bundle(object):
                 raise errors.CliError(
                     "node name must be set in the kube-matrix before audit")
 
-
         LOGGER.debug("---- %s", inventory)
         var_dict = {"ignore_assert_errors": True}
 
@@ -765,23 +774,25 @@ class Bundle(object):
             host_list=inventory,
             playbooks="audit",
             vars=get_config_vars_dict(),
-            extra_vars=var_dict)
-        # manage_callback=True,
-        # next_status="auditInProgress",
-        # nodes=node_list)
+            extra_vars=var_dict,
+            manage_callback=True,
+            next_status="auditInProgress",
+            nodes=node_list,
+            category="audit",
+            last_playbook=False)
         LOGGER.debug("result : %s", result)
         if result != 0:
             raise errors.AnsibleError(
                 "Ansible playbook failed: audit")
-                
         result = ansibleplay.AnsibleRunner(tags=['asserts']).playbook(
             host_list=inventory,
             playbooks="/opt/mfvp/deploypattern/ansible/kubespray/cluster",
             vars=get_config_vars_dict(),
-            extra_vars=var_dict)
-        # manage_callback=True,
-        # next_status="auditInProgress",
-        # nodes=node_list)
+            extra_vars=var_dict,
+            manage_callback=True,
+            next_status="auditInProgress",
+            nodes=node_list,
+            category="audit")
         LOGGER.debug("result : %s" % result)
         if result != 0:
             raise errors.AnsibleError(
@@ -907,7 +918,8 @@ class Bundle(object):
                 extra_vars=var_dict,
                 manage_callback=True,
                 next_status="deploymentInProgress",
-                nodes=node_list)
+                nodes=node_list,
+                category="deploy")
 
             LOGGER.info("-------result of LOGGER.info on result command:")
             LOGGER.info("result : %s", result)
@@ -984,7 +996,8 @@ class Bundle(object):
                 extra_vars=var_dict,
                 manage_callback=True,
                 next_status="deleteInProgress",
-                nodes=node_list)
+                nodes=node_list,
+                category="reset")
 
             LOGGER.info("-------result of LOGGER.info on result command:")
             LOGGER.info("result : %s", result)
