@@ -21,8 +21,6 @@ from __future__ import (absolute_import, division, print_function)
 
 import os
 import logging
-import tempfile
-import shutil
 import tarfile
 import re
 import subprocess
@@ -34,25 +32,25 @@ import ericsson.deploypattern.lib.errors as errors
 from ericsson.deploypattern.lib.dockerlib import DockerLib
 from ericsson.deploypattern.lib.config import Config
 from ericsson.deploypattern.lib.config import get_compose_path
+from ericsson.deploypattern.lib.utils import create_tmp_dir, cleanup
 
-logger = logging.getLogger(__name__)
+LOGGER = logging.getLogger(__name__)
 
 
-REGISTRY_VOLUME_PATH    = r'/var/lib/'
+REGISTRY_VOLUME_PATH = r'/var/lib/'
 REGISTRY_CONTAINER_NAME = r'registry'
-REGISTRY_DEFAULT_PORT=5000
+REGISTRY_DEFAULT_PORT = 5000
 TMP_DIR_MIN_SIZE = 4 # GB
 
 
 def start_docker_registry():
     """ Start the docker registry """
-
     docker = DockerLib()
 
     try:
         registry_version = Config().get('docker', 'registry_version')
-    except Exception as e:
-        raise errors.InvalidConfig(e)
+    except Exception as msg:
+        raise errors.InvalidConfig(msg)
 
     registry_name = REGISTRY_CONTAINER_NAME
     image_name = registry_name + ':' + registry_version
@@ -60,10 +58,23 @@ def start_docker_registry():
     def _recreate_registry():
         """Inner version called if registry need to be create/recreate """
 
+        # get all compose container names and remove all compose containers
+        # BUGFIX52250
+        cmd = "cd %s && sudo docker-compose -f ./compose_mdt.yaml ps --services" % \
+              get_compose_path()
+        proc = subprocess.Popen(cmd, shell=True, stdout=subprocess.PIPE,
+                                stderr=subprocess.PIPE)
+        (proc_output, _) = proc.communicate()
+        proc.wait()
+
+        for container in proc_output.split('\n')[0:-1]:
+            docker.rm_container_if_running(container)
+
+
         img = docker.docker.images.get(name=image_name)
 
         # stop and delete registry container
-        docker.rm_container_if_running(registry_name)    
+        docker.rm_container_if_running(registry_name)
 
         # create & start
         registry_container = docker.docker.containers.create(
@@ -79,10 +90,10 @@ def start_docker_registry():
 
         registry_container.start()
 
-        logger.info(":: docker registry created: name=%s version=%s status=%s" %
-                    (registry_container.name,
-                     registry_version,
-                     registry_container.status))
+        LOGGER.info(":: docker registry created: name=%s version=%s status=%s",
+                    registry_container.name,
+                    registry_version,
+                    registry_container.status)
 
     try:
 
@@ -92,42 +103,32 @@ def start_docker_registry():
         containers_list = docker.docker.containers.list(all=True)
 
         if not any(c.name == registry_name for c in containers_list):
-            logger.info(":: Registry container doesn't exist, will be created")
+            LOGGER.info(":: Registry container doesn't exist, will be created")
             _recreate_registry()
 
-        else :
+        else:
 
-            currentPorts = docker.docker_api.inspect_container(registry_name)['HostConfig']['PortBindings']
-            #Get current containerPort and hostPort, ie. 5000
-            containerPort = currentPorts.keys()[0].split("/")[0]
-            hostPort = currentPorts.get(currentPorts.keys()[0])[0]['HostPort']
+            cur_ports = docker.docker_api.inspect_container(registry_name)['HostConfig']['PortBindings']
+            #Get current container_port and host_port, ie. 5000
+            container_port = cur_ports.keys()[0].split("/")[0]
+            host_port = cur_ports.get(cur_ports.keys()[0])[0]['HostPort']
 
-            if ((containerPort != str(REGISTRY_DEFAULT_PORT)) or
-            (hostPort != str(docker.registry_port)) or
-            (any((ctn.name == registry_name and ctn.status != 'running') for ctn in containers_list))):
-
-                logger.info(":: Registry parameters have been modified, registry will be recreated")
-                # get all compose container names and remove all compose containers 
-                # BUGFIX52250 
-                cmd = "cd %s && sudo docker-compose -f ./compose_mdt.yaml ps --services" % get_compose_path()
-                proc = subprocess.Popen(cmd, shell=True, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
-                (proc_output, proc_error) = proc.communicate()
-                proc.wait()
-
-                for c in proc_output.split('\n')[0:-1]:
-                    docker.rm_container_if_running(c)
+            if ((container_port != str(REGISTRY_DEFAULT_PORT)) or
+                    (host_port != str(docker.registry_port)) or
+                    (any((ctn.name == registry_name and ctn.status != 'running') for ctn in containers_list))):
 
+                LOGGER.info(":: Registry parameters have been modified, registry will be recreated")
                 # recreate registry container
                 _recreate_registry()
 
     except ImageNotFound:
-        logger.error('Registry image -%s- not found' % image_name)
+        LOGGER.error('Registry image -%s- not found', image_name)
         raise
     except APIError:
-        logger.error('Starting registry failed: server Error')
+        LOGGER.error('Starting registry failed: server Error')
         raise
-    except errors.InitError as e:
-        logger.error("ERROR: %s" % e)
+    except errors.InitError as msg:
+        LOGGER.error("ERROR: %s", msg)
         raise
 
 def mount_registry_nfs(address, path):
@@ -142,7 +143,7 @@ def mount_registry_nfs(address, path):
     fstype = "nfs"
 
     # Add permanent mount (case reboot) if not already in /etc/fstab
-    with open('/etc/fstab','ab+') as fstab:
+    with open('/etc/fstab', 'ab+') as fstab:
         if source not in fstab.read():
             fstab.write("\n" + source + " " + target + " nfs defaults 0 0")
         fstab.close()
@@ -150,21 +151,28 @@ def mount_registry_nfs(address, path):
     if not os.path.exists(target):
         os.makedirs(target)
 
-    logger.info(":: docker registry NFS Storage mount: source=%s target=%s" %
-                (source,
-                 target))
-    try:
-        proc = subprocess.Popen(["mount", "-t", fstype, source, target],
-                         stdout=subprocess.PIPE, stderr=subprocess.PIPE)
-        proc.wait()
-    except OSError as e:
-        logger.error('Error while mounting NFS: %s' % e.strerror)
-        raise
-    except:
-        raise
+    LOGGER.info(":: docker registry NFS Storage mount: source=%s target=%s", source, target)
+    # test if NFS already mounted, not to mount again
+    cmd = "mount -l | grep " + source
+    proc = subprocess.Popen(cmd, shell=True,
+                            stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+    (_, proc_error) = proc.communicate()
+    LOGGER.info("mount %s", source)
+    if proc.returncode != 0:
+        try:
+            proc = subprocess.Popen(["mount", "-t", fstype, source, target],
+                                    stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+            (_, proc_error) = proc.communicate()
+            if proc.returncode != 0:
+                raise errors.InitError(proc_error)
+        except OSError as msg:
+            LOGGER.error('Error while mounting NFS: %s', msg.strerror)
+            raise
+        except:
+            raise
 
 
-def load_docker_registry(path_tgz=None,path_dir=None,registry=None):
+def load_docker_registry(path_tgz=None, path_dir=None, registry=None):
     """
     Upload containers to the Docker registry used by MDT (default or external)
     :param path_tgz:
@@ -177,17 +185,17 @@ def load_docker_registry(path_tgz=None,path_dir=None,registry=None):
             for item in os.listdir(path_dir):
                 item_path = os.path.join(path_dir, item)
                 if os.path.isdir(item_path):
-                    load_docker_registry(path_dir=item_path,registry=registry)
+                    load_docker_registry(path_dir=item_path, registry=registry)
                 else:
-                    load_targz(item_path,registry)
+                    load_targz(item_path, registry)
         else:
-             raise errors.LoadError("Directory %s not found ! " % path_dir)
+            raise errors.LoadError("Directory %s not found ! " % path_dir)
 
     elif path_tgz:
-        load_targz(path_tgz,registry)
+        load_targz(path_tgz, registry)
 
 
-def load_targz(tgz,registry=None):
+def load_targz(tgz, registry=None):
     """
 
     :param tgz:
@@ -198,14 +206,14 @@ def load_targz(tgz,registry=None):
     docker = DockerLib()
     tmp = None
     try:
-        logger.info(":: loading containers from %s" % tgz)
+        LOGGER.info(":: loading containers from %s", tgz)
 
         # Check if file exist
         if not os.path.exists(tgz):
             raise errors.LoadError("file %s not found ! " % tgz)
 
         tgz_size = os.stat(tgz).st_size
-        tmp = _create_tmp_dir(tgz_size)
+        tmp =create_tmp_dir(tgz_size)
         if tmp is None:
             raise errors.LoadError("Need %s GB free space" % TMP_DIR_MIN_SIZE)
 
@@ -216,25 +224,32 @@ def load_targz(tgz,registry=None):
         tar = tarfile.open(tgz)
 
         def _load(_img, _img_path):
+            """
+
+            :param _img:
+            :param _img_path:
+            :return:
+            """
             # load image(s)  locally
             images = docker.load_tgz_image(_img_path)
             # push them on registry only if they are loaded in the previous step
             # it means that there isn't already image with the same tag
             # and of course the registry is up
             for image in images:
-                #If repository identified in image name, remove repository info by renaming image
+                #If repository identified in image name,
+                # remove repository info by renaming image
                 if "/" in image:
-                    oldrepo,image_new=image.rsplit('/', 1)
-                    full_name,img_tag=image_new.split(':')
+                    oldrepo, image_new = image.rsplit('/', 1)
+                    full_name, img_tag = image_new.split(':')
                     img = docker.docker.images.get(image)
                     img.tag(full_name, img_tag)
                     docker.docker.images.remove(image)
                 #If no repo info in name, split as usual
                 else:
-                    full_name,img_tag=image.split(':')
+                    full_name, img_tag = image.split(':')
                 docker.push_image(full_name, img_tag)
             else:
-                logger.info("")
+                LOGGER.info("")
 
         multi_cont = True
         for member in tar.getmembers():
@@ -266,21 +281,23 @@ def load_targz(tgz,registry=None):
         if not multi_cont:
             _load(tgz, os.path.join('', tgz))
 
-    except Exception as e:
-        __cleanup(tmp)
+    except Exception:
+        cleanup(tmp)
         raise #errors.LoadError(e)
     finally:
-        __cleanup(tmp)
-
-
-def __cleanup(tmp):
-    if tmp is not None and os.path.exists(tmp):
-        shutil.rmtree(tmp)
+        cleanup(tmp)
 
 
 def _extract_tarfile(tar, member, tmp):
+    """
 
-    logger.debug("extracting image: %s " % member.name)
+    :param tar:
+    :param member:
+    :param tmp:
+    :return:
+    """
+
+    LOGGER.debug("extracting image: %s ", member.name)
 
     if member.name.endswith('.tar') or \
             member.name.endswith('.tar.gz') or \
@@ -297,32 +314,10 @@ def _extract_tarfile(tar, member, tmp):
                 "suspicious filename start with /")
 
         # extract image
-        logger.info("  -> extracting %s" % member.name)
+        LOGGER.info("  -> extracting %s", member.name)
         tar.extract(member, path=tmp)
 
         return member.name
     else:
         raise errors.LoadError(
-            "containers in archive must be .tar - .tar.gz or .tgz file")
-
-
-def _create_tmp_dir(size):
-    """ Create a temp directory to extract tar.gz file """
-    # TODO check /tmp space otherwise use ~/
-
-    def check_free(tmpdir):
-        _ret = False
-        f = os.statvfs(tmpdir)
-        free_size = f.f_frsize * f.f_bavail
-        logger.debug(" free space on %s =  %s" % (tmpdir, free_size))
-        if free_size > size:
-            _ret = True
-        return _ret
-
-    # check free size in /tmp /var or /home
-    tmp_list = [tempfile.gettempdir(), '/var', os.environ['HOME']]
-    for _tmp in tmp_list:
-        if check_free(_tmp):
-            return tempfile.mkdtemp(dir=_tmp)
-
-    return None
+            "containers in archive must be .tar - .tar.gz or .tgz file")
\ No newline at end of file
